==> 3.5.12-core.tar: kdenetwork/kopete/protocols/groupwise/libgroupwise/connector.h <==
/*
    Kopete Groupwise Protocol
    connector.h - the Groupwise socket connector

    Copyright (c) 2004      SUSE Linux AG	 	 http://www.suse.com
    
    Based on Iris, Copyright (C) 2003  Justin Karneges

    Kopete (c) 2002-2004 by the Kopete developers <kopete-devel@kde.org>
 
    *************************************************************************
    *                                                                       *
    * This library is free software; you can redistribute it and/or         *
    * modify it under the terms of the GNU Lesser General Public            *
    * License as published by the Free Software Foundation; either          *
    * version 2 of the License, or (at your option) any later version.      *
    *                                                                       *
    *************************************************************************
*/

#ifndef LIBGW_CONNECTOR_H
#define LIBGW_CONNECTOR_H

#include <tqhostaddress.h>
#include <tqobject.h>

class ByteStream;

class Connector : public QObject
{
	Q_OBJECT
public:
	Connector(TQObject *parent=0);
	virtual ~Connector();

	virtual void connectToServer(const TQString &server)=0;
	virtual ByteStream *stream() const=0;
	virtual void done()=0;

	bool useSSL() const;
	bool havePeerAddress() const;
	TQHostAddress peerAddress() const;
	Q_UINT16 peerPort() const;

signals:
	void connected();
	void error();

protected:
	void setUseSSL(bool b);
	void setPeerAddressNone();
	void setPeerAddress(const TQHostAddress &addr, Q_UINT16 port);

private:
	bool ssl;
	bool haveaddr;
	TQHostAddress addr;
	Q_UINT16 port;
};

#endif

==> 3.5.13-core.tar: kdenetwork/kopete/protocols/groupwise/libgroupwise/connector.h <==
/*
    Kopete Groupwise Protocol
    connector.h - the Groupwise socket connector

    Copyright (c) 2004      SUSE Linux AG	 	 http://www.suse.com
    
    Based on Iris, Copyright (C) 2003  Justin Karneges

    Kopete (c) 2002-2004 by the Kopete developers <kopete-devel@kde.org>
 
    *************************************************************************
    *                                                                       *
    * This library is free software; you can redistribute it and/or         *
    * modify it under the terms of the GNU Lesser General Public            *
    * License as published by the Free Software Foundation; either          *
    * version 2 of the License, or (at your option) any later version.      *
    *                                                                       *
    *************************************************************************
*/

#ifndef LIBGW_CONNECTOR_H
#define LIBGW_CONNECTOR_H

#include <tqhostaddress.h>
#include <tqobject.h>

class ByteStream;

class Connector : public TQObject
{
	Q_OBJECT
  TQ_OBJECT
public:
	Connector(TQObject *parent=0);
	virtual ~Connector();

	virtual void connectToServer(const TQString &server)=0;
	virtual ByteStream *stream() const=0;
	virtual void done()=0;

	bool useSSL() const;
	bool havePeerAddress() const;
	TQHostAddress peerAddress() const;
	TQ_UINT16 peerPort() const;

signals:
	void connected();
	void error();

protected:
	void setUseSSL(bool b);
	void setPeerAddressNone();
	void setPeerAddress(const TQHostAddress &addr, TQ_UINT16 port);

private:
	bool ssl;
	bool haveaddr;
	TQHostAddress addr;
	TQ_UINT16 port;
};

#endif
